@@ -5,14 +5,14 @@
 #' @param pkg package description, can be path or package name.  See
 #'   \code{\link{as.package}} for more information
 #' @export
-missing_s3 <- function(pkg = NULL) {
+missing_s3 <- function(pkg = ".") {
   pkg <- as.package(pkg)
-  ns <- parseNamespaceFile(basename(pkg$path), dirname(pkg$path))
+  ns <- parse_ns_file(pkg)
 
   exports <- paste(ns$S3methods[, 1], ns$S3methods[, 2], sep = ".")
 
   load_all(pkg)
-  objs <- ls(env_name(pkg))
+  objs <- ls(ns_env(pkg))
   s3_objs <- objs[grepl(".", objs, fixed = TRUE)]
 
   setdiff(s3_objs, exports)
