@@ -7,25 +7,23 @@
 #' }
 #' @param x object to coerce to a package
 #' @export
+#' @keywords internal
 as.package <- function(x = NULL) {
   if (is.package(x)) return(x)
 
-  if (is.null(x)) {
-    stop("pkg must not be NULL", call. = FALSE)
-  }
-
-  path <- find_package(x)
-
-  pkg <- load_pkg_description(path)
+  x <- check_dir(x)
+  load_pkg_description(x)
 }
 
 
-find_package <- function(x, check_desc = TRUE) {
-  if (is.null(x)) return(FALSE)
+check_dir <- function(x) {
+  if (is.null(x)) {
+    stop("Path is null", call. = FALSE)
+  }
 
-  # Strip trailing slashes (needed only for windows)
-  x <- normalizePath(x, mustWork = FALSE)
-  x <- gsub("\\\\$", "", x)
+  # Normalise path and strip trailing slashes
+  x <- gsub("\\\\", "/", x, fixed = TRUE)
+  x <- sub("/*$", "", x)
 
   if (!file.exists(x)) {
     stop("Can't find directory ", x, call. = FALSE)
@@ -34,16 +32,10 @@ find_package <- function(x, check_desc = TRUE) {
     stop(x, " is not a directory", call. = FALSE)
   }
 
-  desc_path <- file.path(x, "DESCRIPTION")
-  if (check_desc && !file.exists(desc_path)) {
-    stop("No DESCRIPTION file found in ", x, call. = FALSE)
-  }
-
   x
 }
 
-#' Load package DESCRIPTION into convenient form.
-#' @keywords internal
+# Load package DESCRIPTION into convenient form.
 load_pkg_description <- function(path) {
   path <- normalizePath(path)
   path_desc <- file.path(path, "DESCRIPTION")
@@ -61,6 +53,7 @@ load_pkg_description <- function(path) {
 
 
 #' Is the object a package?
+#'
 #' @keywords internal
 #' @export
 is.package <- function(x) inherits(x, "package")
